# This is a set of scripts for finding the lipid order parameter from
# coordinate data.  The lipid order parameter is defined as
#     S_CD = < 3/2 cos^2 w - 1/2 >
# where w is the angle made by the bond between an aliphatic carbon
# and a hydrogen. 

# Author: Justin Gullingsrud
# Email:  justinrocks@gmail.com

# Adjusted by: Jeffery Klauda
# Email: jbklauda@umd.edu

# Find order param for the cholesterol  

proc orderparam { seltext n2 fn } {
# Setup output file
  set filename "chol-$fn.dat"
  set fileId [open $filename "w"]

  set n [molinfo top get numframes]

# Do all carbons to end average all hydrogens

  for { set i 1 } { $i <= $n2 } { incr i } {
    set cp [atomselect top "($seltext) and name C$i"]
    if { [$cp num] == 0 } {
      puts "skipping $i"
    }
    set hx [atomselect top "($seltext) and name H${i}A"]
    set hy [atomselect top "($seltext) and name H${i}B"]
    set hz [atomselect top "($seltext) and name H${i}C"] 
# added for some cases of single hydrogen carbons
    set h9 [atomselect top "($seltext) and name H${i}"]
    set sum 0.0
    set nh 0
    set nres [$cp num]
    for { set frame 0 } { $frame < $n } { incr frame } {
      $cp frame $frame
      $hx frame $frame
      $hy frame $frame
	$hz frame $frame
	$h9 frame $frame
      set cpx [$cp get x]
      set cpy [$cp get y]
      set cpz [$cp get z]

      if { [$hx num] != 0 } {
        set hxx [vecsub $cpx [$hx get x]]
        set hxy [vecsub $cpy [$hx get y]]
        set hxz [vecsub $cpz [$hx get z]]
        foreach dx $hxx dy $hxy dz $hxz {
          set norm2 [expr {$dx*$dx + $dy*$dy + $dz*$dz}]
          set sum [expr {$sum + $dz*$dz/$norm2}]
        }
        incr nh $nres
      }

      if { [$hy num] != 0 } {
        set hyx [vecsub $cpx [$hy get x]]
        set hyy [vecsub $cpy [$hy get y]]
        set hyz [vecsub $cpz [$hy get z]]
        foreach dx $hyx dy $hyy dz $hyz {
          set norm2 [expr {$dx*$dx + $dy*$dy + $dz*$dz}]
          set sum [expr {$sum + $dz*$dz/$norm2}]
        }
        incr nh $nres
      }

      if { [$hz num] != 0 } {
        set hzx [vecsub $cpx [$hz get x]]
        set hzy [vecsub $cpy [$hz get y]]
        set hzz [vecsub $cpz [$hz get z]]
        foreach dx $hzx dy $hzy dz $hzz {
          set norm2 [expr {$dx*$dx + $dy*$dy + $dz*$dz}]
          set sum [expr {$sum + $dz*$dz/$norm2}]
        }
        incr nh $nres
      }

      if { [$h9 num] != 0 } {
        set h9x [vecsub $cpx [$h9 get x]]
        set h9y [vecsub $cpy [$h9 get y]]
        set h9z [vecsub $cpz [$h9 get z]]
        foreach dx $h9x dy $h9y dz $h9z {
          set norm2 [expr {$dx*$dx + $dy*$dy + $dz*$dz}]
          set sum [expr {$sum + $dz*$dz/$norm2}]
        }
        incr nh $nres
      }

    }
    if { [$hx num] == 0 && [$hy num] == 0 && [$hz num] == 0 && [$h9 num] == 0 } {
    } else { 
    set arr($i) [expr {-1.5*$sum/$nh + 0.5}]
    puts $fileId "C$i [expr {-1.5*$sum/$nh + 0.5}]"
    }
  }
  close $fileId
}
